@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-/* Copyright (C) 1998 Red Hat, Inc., Tom Tromey
+/* Copyright (C) 1998, 1999 Red Hat, Inc., Tom Tromey
  * Authors: Jonathan Blandford <jrb@redhat.com>
  * Authors: Tom Tromey <tromey@cygnus.com>
  */
@@ -103,8 +103,16 @@ mouse_help (void)
 
   tmp = gnome_help_file_find_file ("users-guide", "gccperiph.html#GCCMOUSE");
   if (tmp) {
-    gnome_help_goto(0, tmp);
-    g_free(tmp);
+          gnome_help_goto(0, tmp);
+          g_free(tmp);
+  } else {
+          GtkWidget *mbox;
+          
+          mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
+                                       GNOME_MESSAGE_BOX_ERROR,
+                                       _("Close"), NULL);
+
+          gtk_widget_show(mbox);
   }
 
 }
@@ -119,7 +127,7 @@ mouse_apply (void)
 
         /* Ignore buttons above 3 -- these are assumed to be a wheel.
            If we have a non-wheeled mouse, this may do weird things */
-        max = MAX (mouse_nbuttons, 3);
+        max = MIN (mouse_nbuttons, 3);
         for (i = 0; i < max; ++i)
                 buttons[i] = mouse_rtol ? (max - i) : (i + 1);
         for (; i < mouse_nbuttons; ++i)
