@@ -5,14 +5,16 @@
 #include "control-center.h"
 #include <gnome.h>
 #include <gdk/gdkx.h>
+#include "gtk-multiview.h"
 
 /* variables */
-extern GtkWidget *container;
-extern GtkWidget *notebook;
+extern GtkWidget *multiview;
 extern GtkWidget *splash_screen;
 extern GtkWidget *hack_widget;
+extern GtkWidget *help_menu_item;
+
 extern gchar *ior;
-static gint current_page = 0;
+static gint page_count = 0;
 static gint id = 0;
 gint destroying = FALSE;
 GList *capplet_list = NULL;
@@ -40,12 +42,12 @@ static void try_button_callback(GtkWidget *widget, gpointer data);
 static void revert_button_callback(GtkWidget *widget, gpointer data);
 static void ok_button_callback(GtkWidget *widget, gpointer data);
 static void cancel_button_callback(GtkWidget *widget, gpointer data);
-static void help_button_callback(GtkWidget *widget, gpointer data);
 static void close_capplet (gboolean show_splash, gpointer data);
 static void exec_capplet (node_data *data);
 static void shutdown_capplet (node_data *nd);
 static void capplet_close_callback (GtkWidget *widget, gpointer data);
 static void capplet_close_callback2 (GtkWidget *widget, gpointer data);
+
 node_data *
 find_node_by_id (gint id)
 {
@@ -94,7 +96,7 @@ exec_capplet (node_data *data)
 
         temp = g_malloc (sizeof (char[17]));
         sprintf (temp, "--xid=");
-        sprintf (temp + 6, "%d",  GDK_WINDOW_XWINDOW (data->socket->window));
+        sprintf (temp + 6, "%ld",  GDK_WINDOW_XWINDOW (data->socket->window));
         argv[1] = temp;
 
         argv[2] = NULL;
@@ -114,15 +116,17 @@ launch_capplet (node_data *data, gboolean exec_new)
         GtkWidget *separator;
         GtkWidget *bbox;
         GtkWidget *frame;
+        GtkWidget *page;
         GList *temp;
-        gint page;
-        gboolean show_splash = TRUE; 
+        gboolean show_splash = TRUE;
+        gchar *help_string;
+        guint signal_id;
         
         /* If the page has not been changed, nuke it, or tell it to hide itself */
-        if ((current_page > 0) && (data->gde->exec_length)) {
-                page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+        if ((page_count > 0) && (data->gde->exec_length)) {
+                page = gtk_multiview_get_current (GTK_MULTIVIEW (multiview));
                 for (temp = capplet_list; temp; temp = temp->next)
-                        if (temp->data && ((node_data*)temp->data)->notetab_id == page) {
+                        if (temp->data && ((node_data*)temp->data)->child == page) {
                                 if (((node_data*)temp->data)->id == data->id) {
                                         return;
                                 } else if (((node_data*)temp->data)->modified == FALSE) {
@@ -145,19 +149,6 @@ launch_capplet (node_data *data, gboolean exec_new)
         /* set up the notebook if needed */
         /* This capplet has not been started yet.  We need to do that. */
         if ((data->id == -1) && (data->gde->exec_length)) {
-                if (notebook == NULL) {
-                        notebook = gtk_notebook_new();
-                        gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
-                        gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
-                        /* show we only want to remove the splashscreen if it's showing */
-                        if (show_splash) {
-                                gtk_widget_ref (splash_screen);
-                                gtk_container_remove (GTK_CONTAINER (container), splash_screen);
-                        }
-                        gtk_container_add (GTK_CONTAINER (container), notebook);
-                        gtk_widget_show (notebook);
-                } 
-
                 vbox = gtk_vbox_new(FALSE, 0);
                 data->socket = gtk_socket_new ();
                 gtk_signal_connect (GTK_OBJECT (data->socket), "destroy", capplet_close_callback, data);
@@ -186,10 +177,6 @@ launch_capplet (node_data *data, gboolean exec_new)
                 data->cancel_button = gtk_button_new_with_label (_("Cancel"));
                 gtk_container_add (GTK_CONTAINER (bbox), data->cancel_button);
                 gtk_signal_connect (GTK_OBJECT (data->cancel_button), "clicked", GTK_SIGNAL_FUNC (cancel_button_callback), data);
-                data->help_button = gtk_button_new_with_label (_("Help"));
-                gtk_container_add (GTK_CONTAINER (bbox), data->help_button);
-                gtk_signal_connect (GTK_OBJECT (data->help_button), "clicked", GTK_SIGNAL_FUNC (help_button_callback), data);
-                
                 /* put it all together */
                 frame = gtk_frame_new (NULL);
                 gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
@@ -199,12 +186,28 @@ launch_capplet (node_data *data, gboolean exec_new)
                 gtk_box_pack_end (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
                 gtk_box_pack_end (GTK_BOX (vbox), separator, FALSE, FALSE, GNOME_PAD_SMALL);
 
+                /* set the help item */
+                help_string = g_strdup_printf (_("Help with '%s' settings"),
+                                               data->gde->name);
+                gtk_label_set_text (GTK_LABEL (GTK_BIN (help_menu_item)->child),
+                                    help_string);
+                signal_id = (guint) gtk_object_get_data (GTK_OBJECT (help_menu_item), "help_signal_id");
+                if (signal_id != 0)
+                        gtk_signal_disconnect (GTK_OBJECT (help_menu_item), signal_id);
+                signal_id = gtk_signal_connect (GTK_OBJECT (help_menu_item), "activate",
+                                                item_help_callback, data);
+                gtk_object_set_data (GTK_OBJECT (help_menu_item), "help_signal_id", (gpointer) signal_id);
+                g_free (help_string);
+                gtk_widget_show (help_menu_item);
+                
                 /* this is in case we ever go back to tabs:
                  * We want to keep tabs on this so we can change the text. */
                 data->label = gtk_label_new (data->gde->name);
-                gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, data->label);
+                gtk_multiview_append_child (GTK_MULTIVIEW (multiview), vbox);
+                gtk_multiview_set_current (GTK_MULTIVIEW (multiview), vbox);
                 gtk_widget_show_all (vbox);
-                data->notetab_id = current_page++;
+                page_count++;
+                data->child = vbox;
                 data->id = id++;
 
                 if (exec_new) {
@@ -214,8 +217,8 @@ launch_capplet (node_data *data, gboolean exec_new)
                         gtk_ctree_select (data->ctree, data->node);
                 }
         }
-        if (data->notetab_id != -1) {
-                gtk_notebook_set_page (GTK_NOTEBOOK (notebook), data->notetab_id);
+        if (data->child != NULL) {
+                gtk_multiview_set_current (GTK_MULTIVIEW (multiview), data->child);
                 if (data->capplet && exec_new) {
                         GNOME_capplet_page_shown (data->capplet,
                                                   data->id,
@@ -225,7 +228,7 @@ launch_capplet (node_data *data, gboolean exec_new)
         }
 }
 void
-revert_all ()
+revert_all (void)
 {
         GList *list;
         node_data *nd;
@@ -345,8 +348,6 @@ queue_socket_destruction (node_data *nd)
 }
 static void
 shutdown_capplet (node_data *nd) {
-       GList *temp;
-
        if (nd->state == CAPPLET_ACTIVE &&
            nd->socket && GTK_SOCKET (nd->socket)->plug_window == NULL) {
                /* Uh oh... We are shutting down a capplet that hasn't realized
@@ -357,7 +358,7 @@ shutdown_capplet (node_data *nd) {
                queue_socket_destruction (nd);
        }
        nd->socket = NULL;
-       gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), nd->notetab_id);
+       gtk_container_remove (GTK_CONTAINER (multiview), nd->child);
        nd->id = -1;
        nd->modified = FALSE;
        nd->state = CAPPLET_INACTIVE;
@@ -366,14 +367,10 @@ shutdown_capplet (node_data *nd) {
                CORBA_Object_release (nd->capplet, &ev);
                nd->capplet = NULL;
        }
-       for (temp = capplet_list; temp; temp = temp->next)
-               if (((node_data*)temp->data)->notetab_id > nd->notetab_id)
-                       ((node_data*)temp->data)->notetab_id -=1;
-               
-       nd->notetab_id = -1;
+       nd->child = NULL;
 }
 /* If show_splash is true, then that means that we want to handle whatever is underneath
- * (ie. putting the splashscreen back, changing the selected node etc. )
+ * (ie. putting the splash_screen back, changing the selected node etc. )
  * Otherwise we ignore what's underneath (ie. we're about to launch another one.) */
 static void
 close_capplet (gboolean show_splash, gpointer data)
@@ -382,21 +379,18 @@ close_capplet (gboolean show_splash, gpointer data)
         GList *temp;
 
         shutdown_capplet (nd);
-        if (--current_page == 0) {
-                gtk_container_remove (GTK_CONTAINER (container), notebook);
-                notebook = NULL;
+        if (--page_count == 0) {
                 if (show_splash) {
-                        /* if we are only temporarily removing it, we don't show a splash. */
-                        gtk_container_add (GTK_CONTAINER (container), splash_screen);
-                        gtk_widget_unref (splash_screen);
+                        gtk_multiview_set_current (GTK_MULTIVIEW (multiview), splash_screen);
+                        gtk_widget_hide (help_menu_item);
                 }
         } else if (show_splash) {
                 /* we need to find the current page, and highlight it. */
-                gint page;
+                GtkWidget *page;
 
-                page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+                page = gtk_multiview_get_current (GTK_MULTIVIEW (multiview));
                 for (temp = capplet_list; temp; temp = temp->next)
-                        if (((node_data *) temp->data)->notetab_id == page) {
+                        if (((node_data *) temp->data)->child == page) {
                                 GtkCTreeNode *ctnode;
                                 gtk_ctree_select (((node_data *) temp->data)->ctree,
                                                   ((node_data *) temp->data)->node);
@@ -412,10 +406,3 @@ close_capplet (gboolean show_splash, gpointer data)
                         }
         }
 }
-
-static void
-help_button_callback(GtkWidget *widget, gpointer data)
-{
-        node_data *nd = (node_data *) data;
-        GNOME_capplet_help (nd->capplet,nd->id, &ev);
-}
