@@ -37,7 +37,7 @@ struct _node_data
         GtkWidget *socket;
         GtkWidget *label;
         gint id;
-        gint notetab_id;
+        GtkWidget *child;
         gboolean modified;
         GtkWidget *try_button;
         GtkWidget *revert_button;
